>From 8bdaba1e3bd199a2033a88a4fbe4982316a9549a Mon Sep 17 00:00:00 2001
From: Tadas Slotkus <devtadas@gmail.com>
Date: Sun, 21 Aug 2011 20:11:04 +0300
Subject: [carFl mem 62/65] Statics: shutdown_fn to globals

Move shutdown_fn array to globals with its helper variables:
shutdown_fn_count;
may_register_shutdown.

Move programmer_param static global variable to globals structure.

Signed-off-by: Tadas Slotkus <devtadas@gmail.com>
---
 flash.h    |    9 +++++++++
 flashrom.c |   33 ++++++++++++---------------------
 2 files changed, 21 insertions(+), 21 deletions(-)

diff --git a/flash.h b/flash.h
index 254a363..2732120 100644
--- a/flash.h
+++ b/flash.h
@@ -299,6 +299,11 @@ struct decode_sizes {
 	uint32_t spi;
 };
 
+struct shutdown_func_data {
+	int (*func) (void *data);
+	void *data;
+};
+
 #define TMP_BUF_SIZE 60
 
 struct globals {
@@ -338,6 +343,10 @@ struct globals {
 	struct decode_sizes max_rom_decode;
 
 	char *programmer_param;
+	int shutdown_fn_count;
+	int may_register_shutdown;
+	#define SHUTDOWN_MAXFN 32
+	struct shutdown_func_data shutdown_fn[SHUTDOWN_MAXFN];
 };
 void init_globals(globals *g);
 
diff --git a/flashrom.c b/flashrom.c
index 875cff9..c75b866 100644
--- a/flashrom.c
+++ b/flashrom.c
@@ -63,6 +63,8 @@ void init_globals(globals *g)
 	g->superio_count = 0;
 	g->ichspi_bbar = 0;
 	g->programmer_param = NULL;
+	g->shutdown_fn_count = 0;
+	g->may_register_shutdown = 0;
 }
 
 const struct programmer_entry programmer_table[] = {
@@ -395,17 +397,6 @@ const struct programmer_entry programmer_table[] = {
 	{}, /* This entry corresponds to PROGRAMMER_INVALID. */
 };
 
-#define SHUTDOWN_MAXFN 32
-static int shutdown_fn_count = 0;
-struct shutdown_func_data {
-	int (*func) (void *data);
-	void *data;
-} static shutdown_fn[SHUTDOWN_MAXFN];
-/* Initialize to 0 to make sure nobody registers a shutdown function before
- * programmer init.
- */
-static int may_register_shutdown = 0;
-
 static int check_block_eraser(const struct flashchip *flash, int k, int log);
 
 /* Register a function to be executed on programmer shutdown.
@@ -418,19 +409,19 @@ static int check_block_eraser(const struct flashchip *flash, int k, int log);
  */
 int register_shutdown(globals *g, int (*function) (void *data), void *data)
 {
-	if (shutdown_fn_count >= SHUTDOWN_MAXFN) {
+	if (g->shutdown_fn_count >= SHUTDOWN_MAXFN) {
 		msg_perr("Tried to register more than %i shutdown functions.\n",
 			 SHUTDOWN_MAXFN);
 		return 1;
 	}
-	if (!may_register_shutdown) {
+	if (!g->may_register_shutdown) {
 		msg_perr("Tried to register a shutdown function before "
 			 "programmer init.\n");
 		return 1;
 	}
-	shutdown_fn[shutdown_fn_count].func = function;
-	shutdown_fn[shutdown_fn_count].data = data;
-	shutdown_fn_count++;
+	g->shutdown_fn[g->shutdown_fn_count].func = function;
+	g->shutdown_fn[g->shutdown_fn_count].data = data;
+	g->shutdown_fn_count++;
 
 	return 0;
 }
@@ -450,7 +441,7 @@ int programmer_init(globals *g, char *param)
 	/* Default to top aligned flash at 4 GB. */
 	g->flashbase = 0;
 	/* Registering shutdown functions is now allowed. */
-	may_register_shutdown = 1;
+	g->may_register_shutdown = 1;
 	/* Default to allowing writes. Broken programmers set this to 0. */
 	g->programmer_may_write = 1;
 
@@ -471,10 +462,10 @@ int programmer_shutdown(globals *g)
 	int ret = 0;
 
 	/* Registering shutdown functions is no longer allowed. */
-	may_register_shutdown = 0;
-	while (shutdown_fn_count > 0) {
-		int i = --shutdown_fn_count;
-		ret |= shutdown_fn[i].func(shutdown_fn[i].data);
+	g->may_register_shutdown = 0;
+	while (g->shutdown_fn_count > 0) {
+		int i = --g->shutdown_fn_count;
+		ret |= g->shutdown_fn[i].func(g->shutdown_fn[i].data);
 	}
 	return ret;
 }
-- 
1.7.6

